@@ -6,17 +6,17 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.5.2'
-__release__ = 20230107
+__version__ = '0.5.3'
+__release__ = 20230118
 __all__ = ['Rate', 'Speed', 'Velocity']
 
-from unyts.dictionaries import dictionary
-from unyts.unit_class import Unit
-from unyts.helpers.common_classes import unit_or_str, numeric
+from ..dictionaries import dictionary as _dictionary
+from ..unit_class import Unit
+from ..helpers.common_classes import unit_or_str, numeric
 
 
 class Rate(Unit):
-    classUnits = dictionary['Rate']
+    classUnits = _dictionary['Rate']
 
     def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'rate'
@@ -26,7 +26,7 @@ class Rate(Unit):
 
 
 class Speed(Unit):
-    classUnits = dictionary['Speed']
+    classUnits = _dictionary['Speed']
 
     def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'speed'
