@@ -6,19 +6,19 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.5.2'
-__release__ = 20230107
+__version__ = '0.5.3'
+__release__ = 20230118
 __all__ = ['Dimensionless', 'Percentage', 'unitless_names']
 
-from unyts.dictionaries import dictionary
-from unyts.unit_class import Unit
-from unyts.errors import WrongUnitsError
-from unyts.helpers.common_classes import unit_or_str, numeric
-from unyts.dictionaries import unitless_names
+from ..dictionaries import dictionary as _dictionary
+from ..unit_class import Unit
+from ..errors import WrongUnitsError
+from ..helpers.common_classes import unit_or_str, numeric
+from ..dictionaries import unitless_names
 
 
 class Dimensionless(Unit):
-    classUnits = dictionary['Dimensionless']
+    classUnits = _dictionary['Dimensionless']
 
     def __init__(self, value: numeric, units: unit_or_str = None):
         self.name = 'dimensionless'
@@ -36,9 +36,9 @@ class Dimensionless(Unit):
                 raise WrongUnitsError("'" + str(new_unit) + "' for '" + str(self.name) + "'")
         if new_unit is None or len(new_unit) == 0:
             return self.value
-        elif new_unit in dictionary['Percentage']:
+        elif new_unit in _dictionary['Percentage']:
             return Percentage(self.value * 100, new_unit)
-        elif new_unit in dictionary['Dimensionless']:
+        elif new_unit in _dictionary['Dimensionless']:
             return Dimensionless(self.value, new_unit)
         else:
             from .define import units
@@ -49,7 +49,7 @@ class Dimensionless(Unit):
 
 
 class Percentage(Dimensionless):
-    classUnits = dictionary['Percentage']
+    classUnits = _dictionary['Percentage']
 
     def __init__(self, value: numeric, units: unit_or_str = None):
         self.name = 'percentage'
